@@ -218,14 +218,11 @@ bool AudioIOALSA::open()
             return false;
 	}
 
-  	/* start recording */
+	/* start recording */
 	if (_direction & directionRead)
 		snd_pcm_start(m_pcm_capture);
-  	/* enable playing (needed for dmix) */
-	if (_direction & directionWrite)
-		snd_pcm_start(m_pcm_playback);
 
-  	return true;
+	return true;
 }
 
 void AudioIOALSA::close()
@@ -369,7 +366,8 @@ int AudioIOALSA::xrun(snd_pcm_t *pcm)
 	artsdebug("xrun!!\n");
 	if ((err = snd_pcm_prepare(pcm)) < 0)
 		return err;
-	snd_pcm_start(pcm); // ignore error here..
+	if (pcm == m_pcm_capture)
+		snd_pcm_start(pcm); // ignore error here..
 	return 0;
 }
 
@@ -383,7 +381,8 @@ int AudioIOALSA::resume(snd_pcm_t *pcm)
 	if (err < 0) {
 		if ((err = snd_pcm_prepare(pcm)) < 0)
 			return err;
-		snd_pcm_start(pcm); // ignore error here..
+		if (pcm == m_pcm_capture)
+			snd_pcm_start(pcm); // ignore error here..
 	}
 	return 0;
 }
@@ -429,6 +428,10 @@ int AudioIOALSA::write(void *buffer, int size)
 		}
 	}
 
+	// Start the sink if it needs it
+	if (snd_pcm_state( m_pcm_playback ) == SND_PCM_STATE_PREPARED)
+		snd_pcm_start(m_pcm_playback);
+
 	if (length == frames) // Sometimes the fragments are "odd" in alsa
 		return size;
 	else
