@@ -57,14 +57,14 @@ const GslConfig*	gsl_get_config	(void) G_GNUC_CONST;
 /* --- memory allocation --- */
 #define gsl_new_struct(type, n)		((type*) gsl_alloc_memblock (sizeof (type) * (n)))
 #define gsl_new_struct0(type, n)	((type*) gsl_alloc_memblock0 (sizeof (type) * (n)))
-#define gsl_delete_struct(type, mem)	(gsl_delete_structs (type, 1, (mem)))
+#define gsl_delete_struct(type, mem)	gsl_delete_structs (type, 1, (mem))
 #ifndef	__GNUC__
 #  define gsl_delete_structs(type, n, mem)	(gsl_free_memblock (sizeof (type) * (n), (mem)))
 #else					/* provide typesafety if possible */
-#  define gsl_delete_structs(type, n, mem)	({ \
+#  define gsl_delete_structs(type, n, mem)	do { \
   type *__typed_pointer = (mem); \
   gsl_free_memblock (sizeof (type) * (n), __typed_pointer); \
-})
+} while(0)
 #endif
 #define	GSL_ALIGNED_SIZE(size,align)	((align) > 0 ? _GSL_INTERN_ALIGN (((gsize) (size)), ((gsize) (align))) : (gsize) (size))
 #define	_GSL_INTERN_ALIGN(s, a)		(((s + (a - 1)) / a) * a)
