@@ -44,6 +44,10 @@ g_strdup_vprintf (const gchar *format,
 		  va_list      args1)
 {
   gchar *buffer;
+#ifdef HAVE_VASPRINTF
+  if (vasprintf (&buffer, format, args1) < 0)
+    buffer = NULL;
+#else
   va_list args2;
 
   G_VA_COPY (args2, args1);
@@ -52,7 +56,7 @@ g_strdup_vprintf (const gchar *format,
 
   vsprintf (buffer, format, args2);
   va_end (args2);
-
+#endif
   return buffer;
 }
 gchar *
