@@ -87,9 +87,8 @@ void Buffer::writeLongSeq(const vector<long>& seq) {
 void Buffer::writeFloat(float f) {
 	// FIXME: on some machines this may fail badly (there is explicit
 	// float marshalling and demarshalling code in mico/orb/util.cc)
-
-	long *f_as_long = (long *)&f;
-	writeLong(*f_as_long);
+	union { float f; long l; } u = {f};
+	writeLong(u.l);
 }
 
 void Buffer::writeFloatSeq(const std::vector<float>& seq) {
@@ -252,9 +251,10 @@ void Buffer::readLongSeq(vector<long>& result)
 float Buffer::readFloat()
 {
 	// FIXME: see writeFloat()
-	long f_as_long = readLong();
+	union {float f; long l; } u;
+	u.l = readLong();
 
-	if(!_readError) return *(float *)&f_as_long;
+	if(!_readError) return u.f;
 	return 0.0;
 }
 
@@ -339,7 +339,7 @@ string Buffer::toString(const string& name)
 		result += hex[*ci & 0xf];
 	}
 
-	if(name == "") return result;
+	if(name.empty()) return result;
 	return name + ":" + result;
 }
 
@@ -364,7 +364,7 @@ static int stringncmp(const string& s1, const string& s2, size_t n)
 bool Buffer::fromString(const string& data, const string& name)
 {
 	string start = name+":";
-	if(name == "") start = "";
+	if(name.empty()) start = "";
 
 	if(stringncmp(data,start,start.size()) != 0) return false;
 	contents.clear();
