@@ -28,6 +28,8 @@
 #include <vector>
 #include <string>
 
+#include "arts_export.h"
+
 /*
  * BC - Status (2002-03-08): DynamicRequest
  *
@@ -75,7 +77,7 @@ class DynamicRequestPrivate;
  *   if(request.invoke(id)) cout << "success" << endl;
  */
 
-class DynamicRequest {
+class ARTS_EXPORT DynamicRequest {
 public:
 	/**
 	 * creates a dynamic request which will be sent to a specific object
