@@ -24,6 +24,9 @@
 #define FACTORY_H
 
 #include <string>
+
+#include "arts_export.h"
+
 #include "object.h"
 #include "startupmanager.h"
 
@@ -39,7 +42,7 @@ namespace Arts {
 
 class FactoryPrivate;
 
-class Factory : public StartupClass {
+class ARTS_EXPORT Factory : public StartupClass {
 private:
 	FactoryPrivate *d;
 public:
