@@ -28,7 +28,7 @@
  */
 typedef unsigned int uint32;
 
-static void MD5Transform(uint32 buf[4], uint32 in[16]);
+static void MD5Transform(uint32 buf[4], uint32 in[MD5_BINARY_LEN]);
 
 void arts_md5sum(unsigned char *message, long len, char *md5sum)
 {
@@ -36,7 +36,7 @@ void arts_md5sum(unsigned char *message, long len, char *md5sum)
 	int i = 0, j = 0;
 	unsigned char w = '\0';
 	uint32 buffer[4] = { 0x67452301, 0xefcdab89, 0x98badcfe, 0x10325476};
-	uint32 in[16];
+	uint32 in[MD5_BINARY_LEN];
 
 	while((finalsize & 63) != 56) finalsize++;
 	finalsize += 8;
@@ -64,7 +64,7 @@ void arts_md5sum(unsigned char *message, long len, char *md5sum)
 				break;
 			case 3: in[j] |= w << 24;
 					j++;
- 					if(j == 16) {
+ 					if(j == MD5_BINARY_LEN) {
 						MD5Transform(buffer,in);
 						j = 0;
 					}
@@ -115,7 +115,7 @@ void arts_md5sum(unsigned char *message, long len, char *md5sum)
  * reflect the addition of 16 longwords of new data.  MD5Update blocks
  * the data and converts bytes into longwords for this routine.
  */
-static void MD5Transform(uint32 buf[4], uint32 in[16])
+static void MD5Transform(uint32 buf[4], uint32 in[MD5_BINARY_LEN])
 {
     uint32 a = buf[0];
     uint32 b = buf[1];
