@@ -567,8 +567,9 @@ Object_skel::Object_skel() :_remoteSendCount(0), _remoteSendUpdated(false)
 	_connection = Dispatcher::the()->loopbackConnection();
 	_internalData->methodTableInit = false;
 
-	char ioid[1024];
-	sprintf(ioid,"SKEL:%p",this);
+/* big enough for our header + 0x + needed number of hex characters + ending NULL */
+	char ioid[7 + 2*sizeof(void *)+1]; 
+	sprintf(ioid,"SKEL:%p",(void *)this);
 	_internalObjectID = ioid;
 }
 
@@ -907,7 +908,7 @@ long Object_skel::_lookupMethod(const MethodDef& md)
 
 			if(j == md.signature.end() && k == mdm.signature.end())
 			*/
-				return mcount;
+			return mcount;
 		}
 		mcount++;
 	}
@@ -1113,8 +1114,8 @@ Object_stub::Object_stub(Connection *connection, long objectID)
 	if(_connection == Dispatcher::the()->loopbackConnection())
 		_internalData->stubForLocalObject = true;
 
-	char ioid[1024];
-	sprintf(ioid,"STUB:%ld:%p",_objectID,connection);
+	char ioid[128];
+	sprintf(ioid,"STUB:%ld:%p",_objectID,(void *)connection);
 	_internalObjectID = ioid;
 }
 
@@ -1126,12 +1127,10 @@ Object_stub::~Object_stub()
 	 */
 	if(_lookupMethodCache)
 	{
-		long c1 = (long)this,p;
-		for(p=0;p<_lookupMethodCacheSize;p++)
+		for(long p=0;p<_lookupMethodCacheSize;p++)
 		{
-			long pos = 3*p;
-			if(_lookupMethodCache[pos] == c1)
-				_lookupMethodCache[pos] = 0;
+			if(_lookupMethodCache[p].obj == this)
+				_lookupMethodCache[p].obj = NULL;
 		}
 	}
 	_connection->_release();
@@ -1296,28 +1295,29 @@ long Object_stub::_lookupMethod(const MethodDef& methodDef)
 	return returnCode;
 }
 
-long *Object_stub::_lookupMethodCache = 0;
+Object_stub::methodCacheEntry *Object_stub::_lookupMethodCache = 0;
 
 long Object_stub::_lookupMethodFast(const char *method)
 {
 	unsigned long c1 = (unsigned long)this;
 	unsigned long c2 = (unsigned long)method;
-	unsigned long pos = 3*((c1^c2^_lookupCacheRandom)%_lookupMethodCacheSize);
+	unsigned long pos = (c1^c2^_lookupCacheRandom)%_lookupMethodCacheSize;
+	/* FIXME this hashing method sucks. at a bare minimum, we're using only every 4th bin */
 
 	if(!_lookupMethodCache)
-	  _lookupMethodCache=(long *)calloc(_lookupMethodCacheSize,3*sizeof(long));
+	  _lookupMethodCache = new methodCacheEntry[_lookupMethodCacheSize];
 	
-	if(_lookupMethodCache[pos] == c1 && _lookupMethodCache[pos+1] == c2)
-		return _lookupMethodCache[pos+2];
+	if(_lookupMethodCache[pos].obj == this && _lookupMethodCache[pos].method == method)
+		return _lookupMethodCache[pos].ID;
 	
 	Buffer _methodBuffer;
 	_methodBuffer.fromString(method,"method");
 	long methodID = _lookupMethod(MethodDef(_methodBuffer));
 	//cout << "methodID = " << methodID << endl;
 
-	_lookupMethodCache[pos] = c1;
-	_lookupMethodCache[pos+1] = c2;
-	_lookupMethodCache[pos+2] = methodID;
+	_lookupMethodCache[pos].obj = this;
+	_lookupMethodCache[pos].method = method;
+	_lookupMethodCache[pos].ID = methodID;
 	return methodID;
 }
 
@@ -1509,7 +1509,7 @@ void Object_stub::_cleanupMethodCache()
 {
 	if(_lookupMethodCache)
 	{
-		free(_lookupMethodCache);
+		delete[] _lookupMethodCache;
 		_lookupMethodCache = 0;
 	}
 }
