@@ -17,7 +17,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
     Permission is also granted to link this program with the Qt
     library, treating Qt like a library that normally accompanies the
@@ -57,7 +57,8 @@ public:
 	{
 		pfd = fileno(pfile);
 
-		fcntl(pfd, F_SETFL, O_NONBLOCK);
+		int rc = fcntl(pfd, F_SETFL, O_NONBLOCK);
+		assert(rc != -1);
 
 		/*
 		 * calculate stream buffer parameters
