@@ -132,7 +132,7 @@ PlayObject SoundServerV2_impl::createPlayObjectForURL(const std::string& url, co
 	/*
 	 * create a PlayObject and connect it
 	 */
-	if(objectType != "")
+	if(!objectType.empty())
 	{
 		arts_debug("creating %s to play file", objectType.c_str());
 
@@ -180,7 +180,7 @@ PlayObject SoundServerV2_impl::createPlayObjectForStream(InputStream instream, c
 	/*
 	 * create a PlayObject and connect it
 	 */
-	if(objectType != "")
+	if(!objectType.empty())
 	{
 		arts_debug("creating %s to play file", objectType.c_str());
 
